tensap.approximation.bases package
==================================

Submodules
----------

tensap.approximation.bases.full\_tensor\_product\_functional\_basis module
--------------------------------------------------------------------------

.. automodule:: tensap.approximation.bases.full_tensor_product_functional_basis
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.bases.functional\_bases module
---------------------------------------------------

.. automodule:: tensap.approximation.bases.functional_bases
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.bases.functional\_basis module
---------------------------------------------------

.. automodule:: tensap.approximation.bases.functional_basis
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.bases.functional\_basis\_array module
----------------------------------------------------------

.. automodule:: tensap.approximation.bases.functional_basis_array
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.bases.polynomial\_functional\_basis module
---------------------------------------------------------------

.. automodule:: tensap.approximation.bases.polynomial_functional_basis
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.bases.sparse\_tensor\_product\_functional\_basis module
----------------------------------------------------------------------------

.. automodule:: tensap.approximation.bases.sparse_tensor_product_functional_basis
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.bases.sub\_functional\_basis module
--------------------------------------------------------

.. automodule:: tensap.approximation.bases.sub_functional_basis
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.bases.user\_defined\_functional\_basis module
------------------------------------------------------------------

.. automodule:: tensap.approximation.bases.user_defined_functional_basis
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tensap.approximation.bases
   :members:
   :undoc-members:
   :show-inheritance:
